@@ -19,11 +19,5 @@
 
 
 xbrlProcessFootnotes <- function(doc) {
-  if (is.null(res <- .Call("xbrlProcessFootnotes", doc, PACKAGE="XBRL"))) {
-    return (res)
-  }
-  mtc <- regmatches(res$href,
-                    regexec("^.*#(.+)$", res$href))
-  res$factId <- sapply(mtc, function(this) this[2])
-  res
+  .Call("xbrlProcessFootnotes", doc, PACKAGE="XBRL")
 }
